Description
Perform common JavaScript operations in Shiny apps using plain R code.Details
shinyjs lets you perform common JavaScript operations in Shiny
applications without having to know any JavaScript. Examples include: hiding an
element, disabling an input, resetting an input back to its original value,
delaying code execution by a few seconds, and many more useful functions.
shinyjs can also be used to easily run your own custom JavaScript
functions from R.
View a http://daattali.com/shiny/shinyjs-demo/{demo Shiny app}
or see the full https://github.com/daattali/shinyjs{README} on GitHub.